@@ -46,7 +46,6 @@ class NxPyDocs():
                 self.command = single_command
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
-                print(json.dumps(parsed_json,indent=4, sort_keys=True))
                 if "Cannot" in parsed_json:
                     click.secho("No Data To Create File", fg='red')
                 else:
@@ -56,7 +55,6 @@ class NxPyDocs():
             if self.command in self.supported_templates:
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
-                print(json.dumps(parsed_json,indent=4, sort_keys=True))
                 if "Cannot" in parsed_json:
                     click.secho("No Data To Create File", fg='red')
                 else:
@@ -85,11 +83,12 @@ class NxPyDocs():
     def json_file(self, parsed_json):
         with open(' %s.json' % self.command, 'w') as f:
             f.write(json.dumps(parsed_json,indent=4, sort_keys=True))
+        print(json.dumps(parsed_json,indent=4, sort_keys=True))            
         click.secho("JSON file created at %s / %s.json" % (sys.path[0],self.command),
         fg='green')
 
     def yaml_file(self, parsed_json):
-        clean_yaml = yaml.dump(json.loads(json.dumps(parsed_json,indent=4, sort_keys=True)), default_flow_style=False)
+        clean_yaml = yaml.dump(json.loads(json.dumps(parsed_json.replace("!!python/unicode",""),indent=4, sort_keys=True)), default_flow_style=False)
         with open(' %s.yaml' % self.command, 'w') as f:
             f.write(clean_yaml)
         print(clean_yaml)
